import 'package:flutter/material.dart';
import 'package:flutter/foundation.dart';
import 'iroute.dart';

class IRouteRoot extends RouterDelegate<String>
    with ChangeNotifier, PopNavigatorRouterDelegateMixin {
  final GlobalKey<NavigatorState>? navigatorKey;

  late Widget child;
  String url = '/';
  IRouteRoot({required this.child}) : navigatorKey = GlobalKey();

  IRoute? _nested;
  set nested(value) {
    this._nested = value;
  }

  static IRouteRoot of(BuildContext context) {
    final delegate = Router.of(context).routerDelegate;
    assert(delegate is IRouteRoot, 'Delegate type must match');
    return delegate as IRouteRoot;
  }

  @override
  Widget build(BuildContext context) {
    return Navigator(
        key: navigatorKey,
        pages: [
          MaterialPage(
            child: child,
          ),
        ],
        onPopPage: (route, result) {
          return false;
        });
  }

  String get currentConfiguration {
    return url;
  }

  set currentConfiguration(String value) {
    url = value;
    notifyListeners();
  }

  @override
  Future<void> setNewRoutePath(String path) async {
    if (path == url) return SynchronousFuture(null);
    if (this._nested != null) _nested!.setNewRoutePath(path);
    return SynchronousFuture(null);
  }
}
